pub struct AuthorityStorePruningConfig {
pub num_latest_epoch_dbs_to_retain: usize,
pub epoch_db_pruning_period_secs: u64,
pub num_epochs_to_retain: u64,
pub pruning_run_delay_seconds: Option<u64>,
pub max_checkpoints_in_batch: usize,
pub max_transactions_in_batch: usize,
pub periodic_compaction_threshold_days: Option<usize>,
pub num_epochs_to_retain_for_checkpoints: Option<u64>,
pub killswitch_tombstone_pruning: bool,
pub smooth: bool,
pub num_epochs_to_retain_for_indexes: Option<u64>,
}Fields
num_latest_epoch_dbs_to_retain: usizenumber of the latest epoch dbs to retain
epoch_db_pruning_period_secs: u64time interval used by the pruner to determine whether there are any epoch DBs to remove
num_epochs_to_retain: u64number of epochs to keep the latest version of objects for.
Note that a zero value corresponds to an aggressive pruner.
This mode is experimental and needs to be used with caution.
Use u64::MAX to disable the pruner for the objects.
pruning_run_delay_seconds: Option<u64>pruner’s runtime interval used for aggressive mode
max_checkpoints_in_batch: usizemaximum number of checkpoints in the pruning batch. Can be adjusted to increase performance
max_transactions_in_batch: usizemaximum number of transaction in the pruning batch
periodic_compaction_threshold_days: Option<usize>enables periodic background compaction for old SST files whose last modified time is
older than periodic_compaction_threshold_days days.
That ensures that all sst files eventually go through the compaction process
num_epochs_to_retain_for_checkpoints: Option<u64>number of epochs to keep the latest version of transactions and effects for
killswitch_tombstone_pruning: booldisables object tombstone pruning. We don’t serialize it if it is the default value, false.
smooth: boolnum_epochs_to_retain_for_indexes: Option<u64>Implementations
Sourceimpl AuthorityStorePruningConfig
impl AuthorityStorePruningConfig
pub fn set_num_epochs_to_retain(&mut self, num_epochs_to_retain: u64)
pub fn set_num_epochs_to_retain_for_checkpoints( &mut self, num_epochs_to_retain: Option<u64>, )
pub fn num_epochs_to_retain_for_checkpoints(&self) -> Option<u64>
pub fn set_killswitch_tombstone_pruning( &mut self, killswitch_tombstone_pruning: bool, )