pub struct ConsensusConfig {
pub db_path: PathBuf,
pub db_retention_epochs: Option<u64>,
pub db_pruner_period_secs: Option<u64>,
pub max_pending_transactions: Option<usize>,
pub max_submit_position: Option<usize>,
pub submit_delay_step_override_millis: Option<u64>,
pub parameters: Option<Parameters>,
pub listen_address: Option<Multiaddr>,
pub external_address: Option<Multiaddr>,
}Fields
db_path: PathBufdb_retention_epochs: Option<u64>db_pruner_period_secs: Option<u64>max_pending_transactions: Option<usize>Maximum number of pending transactions to submit to consensus, including those in submission wait. Default to 20_000 inflight limit, assuming 20_000 txn tps * 1 sec consensus latency.
max_submit_position: Option<usize>When defined caps the calculated submission position to the max_submit_position. Even if the is elected to submit from a higher position than this, it will “reset” to the max_submit_position.
submit_delay_step_override_millis: Option<u64>The submit delay step to consensus defined in milliseconds. When provided it will override the current back off logic otherwise the default backoff logic will be applied based on consensus latency estimates.
parameters: Option<Parameters>listen_address: Option<Multiaddr>Override for the consensus network listen address. When set, Mysticeti binds to this address instead of deriving from the committee. Address override is advertised via the discovery protocol.
external_address: Option<Multiaddr>External consensus address that should be advertised via the discovery protocol,
if it is different from listen_address above.
When neither this nor listen_address is set, peers use the on-chain committee address.
Implementations
Sourceimpl ConsensusConfig
impl ConsensusConfig
pub fn db_path(&self) -> &Path
pub fn max_pending_transactions(&self) -> usize
pub fn submit_delay_step_override(&self) -> Option<Duration>
pub fn db_retention_epochs(&self) -> u64
pub fn db_pruner_period(&self) -> Duration